@@ -1,5 +1,5 @@
 use self::{case::CaseHandler, hoist::hoist};
-use std::mem::replace;
+use std::mem::take;
 use swc_atoms::js_word;
 use swc_common::{Mark, Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
@@ -78,7 +78,7 @@ impl Regenerator {
                         span: DUMMY_SP,
                         kind: VarDeclKind::Var,
                         declare: false,
-                        decls: replace(&mut self.top_level_vars, Default::default()),
+                        decls: take(&mut self.top_level_vars),
                     }))),
                 );
             }
@@ -411,7 +411,7 @@ impl Regenerator {
                             buf.push(Stmt::Decl(Decl::Var(VarDecl {
                                 span: DUMMY_SP,
                                 kind: VarDeclKind::Var,
-                                decls: replace(&mut self.outer_fn_vars, Default::default()),
+                                decls: take(&mut self.outer_fn_vars),
                                 declare: false,
                             })));
                         }
